==> jc-1.4.0.tar.gz: java/awt/PopupMenu.h <==
// public class java.awt.PopupMenu

// class file dependencies
// @dep_class 41b5e371a0c88c01 java_awt_Menu
// @dep_class 885ed34296e74912 java_awt_MenuComponent
// @dep_class a0a2a32107372b4f java_awt_MenuItem
// @dep_class a1f7970bac9c6f76 java_awt_PopupMenu
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Menu

#include "java/awt/Menu.h"

#ifndef _JC_java_awt_PopupMenu_H_
#define _JC_java_awt_PopupMenu_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_java_awt_PopupMenu$sub_refs	_jc_java_awt_PopupMenu$sub_refs;
typedef struct _jc_java_awt_PopupMenu$sub_nonrefs	_jc_java_awt_PopupMenu$sub_nonrefs;
typedef struct _jc_java_awt_PopupMenu$refs	_jc_java_awt_PopupMenu$refs;
typedef struct _jc_java_awt_PopupMenu$nonrefs	_jc_java_awt_PopupMenu$nonrefs;
typedef struct _jc_java_awt_PopupMenu$object	_jc_java_awt_PopupMenu$object;

typedef struct _jc_java_awt_PopupMenu$fields_struct	_jc_java_awt_PopupMenu$fields_struct;
typedef const struct _jc_java_awt_PopupMenu$vmethods	_jc_java_awt_PopupMenu$vmethods;
typedef const struct _jc_java_awt_PopupMenu$vtable	_jc_java_awt_PopupMenu$vtable;
typedef const struct _jc_java_awt_PopupMenu$vtype	_jc_java_awt_PopupMenu$vtype;

// Class fields structure
struct _jc_java_awt_PopupMenu$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_PopupMenu$fields_struct _jc_java_awt_PopupMenu$class_fields;

// Constructors
extern void _jc_java_awt_PopupMenu$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_PopupMenu$object *);
extern void _jc_java_awt_PopupMenu$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_PopupMenu$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_java_awt_PopupMenu$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_java_awt_PopupMenu$object *);
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_PopupMenu$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_PopupMenu$object *);
extern void _jc_java_awt_PopupMenu$method$show$7b2df54a68d4cb4c(_jc_env *, struct _jc_java_awt_PopupMenu$object *, struct _jc_java_awt_Component$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_PopupMenu$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_java_awt_PopupMenu$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_java_awt_PopupMenu$method_info$show$7b2df54a68d4cb4c;

// Virtual methods structure
struct _jc_java_awt_PopupMenu$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_java_awt_PopupMenu$object *);
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_PopupMenu$object *);
	void	(*show$7b2df54a68d4cb4c)(_jc_env *, struct _jc_java_awt_PopupMenu$object *, struct _jc_java_awt_Component$object *, jint, jint);
};

// Vtable
struct _jc_java_awt_PopupMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_MenuComponent$vmethods	java_awt_MenuComponent;
	_jc_java_awt_MenuItem$vmethods	java_awt_MenuItem;
	_jc_java_awt_Menu$vmethods	java_awt_Menu;
	_jc_java_awt_PopupMenu$vmethods	java_awt_PopupMenu;
};

// Vtype
struct _jc_java_awt_PopupMenu$vtype {
	_jc_type			type;
	_jc_java_awt_PopupMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PopupMenu$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PopupMenu$refs {
    _jc_java_awt_PopupMenu$sub_refs	java_awt_PopupMenu;
    _jc_java_awt_Menu$sub_refs	java_awt_Menu;
    _jc_java_awt_MenuItem$sub_refs	java_awt_MenuItem;
    _jc_java_awt_MenuComponent$sub_refs	java_awt_MenuComponent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PopupMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PopupMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_MenuComponent$sub_nonrefs	java_awt_MenuComponent;
    _jc_java_awt_MenuItem$sub_nonrefs	java_awt_MenuItem;
    _jc_java_awt_Menu$sub_nonrefs	java_awt_Menu;
    _jc_java_awt_PopupMenu$sub_nonrefs	java_awt_PopupMenu;
};

// Object instance structure
struct _jc_java_awt_PopupMenu$object {
	_jc_java_awt_PopupMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PopupMenu$vtype	*vtype;
	_jc_java_awt_PopupMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PopupMenu$vtype _jc_java_awt_PopupMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PopupMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PopupMenu$class_object;

#endif	/* _JC_java_awt_PopupMenu_H_ */

==> jc-1.4.5.tar.gz: java/awt/PopupMenu.h <==
// public class java.awt.PopupMenu

// class file dependencies
// @dep_class 41b5e371a0c88c01 java_awt_Menu
// @dep_class fea490bddca4d2de java_awt_MenuComponent
// @dep_class 8981b653cb4010a1 java_awt_MenuItem
// @dep_class a1f7970bac9c6f76 java_awt_PopupMenu
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Menu

#include "java/awt/Menu.h"

#ifndef _JC_java_awt_PopupMenu_H_
#define _JC_java_awt_PopupMenu_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_java_awt_PopupMenu$sub_refs	_jc_java_awt_PopupMenu$sub_refs;
typedef struct _jc_java_awt_PopupMenu$sub_nonrefs	_jc_java_awt_PopupMenu$sub_nonrefs;
typedef struct _jc_java_awt_PopupMenu$refs	_jc_java_awt_PopupMenu$refs;
typedef struct _jc_java_awt_PopupMenu$nonrefs	_jc_java_awt_PopupMenu$nonrefs;
typedef struct _jc_java_awt_PopupMenu$object	_jc_java_awt_PopupMenu$object;

typedef struct _jc_java_awt_PopupMenu$fields_struct	_jc_java_awt_PopupMenu$fields_struct;
typedef const struct _jc_java_awt_PopupMenu$vmethods	_jc_java_awt_PopupMenu$vmethods;
typedef const struct _jc_java_awt_PopupMenu$vtable	_jc_java_awt_PopupMenu$vtable;
typedef const struct _jc_java_awt_PopupMenu$vtype	_jc_java_awt_PopupMenu$vtype;

// Class fields structure
struct _jc_java_awt_PopupMenu$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_PopupMenu$fields_struct _jc_java_awt_PopupMenu$class_fields;

// Constructors
extern void _jc_java_awt_PopupMenu$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_PopupMenu$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_PopupMenu$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_PopupMenu$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_PopupMenu$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_java_awt_PopupMenu$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_PopupMenu$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_PopupMenu$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_PopupMenu$method$show$7b2df54a68d4cb4c(_jc_env *, struct _jc_java_awt_PopupMenu$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_PopupMenu$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_java_awt_PopupMenu$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_java_awt_PopupMenu$method_info$show$7b2df54a68d4cb4c;

// Virtual methods structure
struct _jc_java_awt_PopupMenu$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_java_awt_PopupMenu$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_PopupMenu$object *) _JC_JCNI_ATTR;
	void	(*show$7b2df54a68d4cb4c)(_jc_env *, struct _jc_java_awt_PopupMenu$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_PopupMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_MenuComponent$vmethods	java_awt_MenuComponent;
	_jc_java_awt_MenuItem$vmethods	java_awt_MenuItem;
	_jc_java_awt_Menu$vmethods	java_awt_Menu;
	_jc_java_awt_PopupMenu$vmethods	java_awt_PopupMenu;
};

// Vtype
struct _jc_java_awt_PopupMenu$vtype {
	_jc_type			type;
	_jc_java_awt_PopupMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PopupMenu$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PopupMenu$refs {
    _jc_java_awt_PopupMenu$sub_refs	java_awt_PopupMenu;
    _jc_java_awt_Menu$sub_refs	java_awt_Menu;
    _jc_java_awt_MenuItem$sub_refs	java_awt_MenuItem;
    _jc_java_awt_MenuComponent$sub_refs	java_awt_MenuComponent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PopupMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PopupMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_MenuComponent$sub_nonrefs	java_awt_MenuComponent;
    _jc_java_awt_MenuItem$sub_nonrefs	java_awt_MenuItem;
    _jc_java_awt_Menu$sub_nonrefs	java_awt_Menu;
    _jc_java_awt_PopupMenu$sub_nonrefs	java_awt_PopupMenu;
};

// Object instance structure
struct _jc_java_awt_PopupMenu$object {
	_jc_java_awt_PopupMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PopupMenu$vtype	*vtype;
	_jc_java_awt_PopupMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PopupMenu$vtype _jc_java_awt_PopupMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PopupMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PopupMenu$class_object;

#endif	/* _JC_java_awt_PopupMenu_H_ */
